package com.ruoyi.pt.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.pt.entity.Events;
import com.ruoyi.pt.service.EventsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.Serializable;
import java.util.List;

/**
 * 事件集合表(Events)表控制层
 *
 * @author wu
 * @since 2023-12-15 23:19:46
 */
@RestController
@RequestMapping("remoteCall/events")
@Api(tags = "事件集合表")
@Transactional(rollbackFor = Exception.class)
public class EventsController extends BaseController {
    /**
     * 服务对象
     */
    @Resource
    private EventsService eventsService;

    /**
     * 分页条件查询所有数据
     *
     * @param page   分页条件
     * @param events 查询条件
     * @return 所有数据
     */
    @GetMapping
    @ApiOperation(value = "分页条件查询事件集合表", response = Events.class)
    public AjaxResult page(Page<Events> page, Events events) {
        return success(eventsService.page(page, events));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    @ApiOperation(value = "通过主键查询单条事件集合表", response = Events.class)
    public AjaxResult getById(@PathVariable Serializable id) {
        QueryWrapper<Events> wrapper = new QueryWrapper<>();
        wrapper.eq("innerEventId", id);
        return success(eventsService.getOne(wrapper));
    }

    /**
     * 新增数据
     *
     * @param events 实体对象
     * @return 新增结果
     */
    @PostMapping
    @ApiOperation(value = "新增事件集合表", response = Events.class)
    public AjaxResult insert(@RequestBody Events events) {
        return success(eventsService.save(events));
    }

    /**
     * 修改数据
     *
     * @param events 实体对象
     * @return 修改结果
     */
    @PutMapping
    @ApiOperation(value = "修改事件集合表")
    public AjaxResult update(@RequestBody Events events) {
        return success(eventsService.updateById(events));
    }

    /**
     * 删除数据
     *
     * @param idList 主键集合
     * @return 删除结果
     */
    @DeleteMapping
    @ApiOperation(value = "删除事件集合表")
    public AjaxResult delete(@RequestParam("idList") List<Long> idList) {
        return success(eventsService.removeByIds(idList));
    }
}

