package com.ruoyi.pt.controller;

import cn.hutool.core.date.LocalDateTimeUtil;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.pt.service.CasesImportService;
import com.ruoyi.pt.service.RemoteCallsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.List;

/**
 * 远程推送算法平台数据
 *
 * @author wu
 * @since 2023/12/15 13:41
 */
@Api(tags = "远程推送算法平台数据⼊")
@RestController
@RequestMapping("/remoteCall")
public class RemoteCallsController extends BaseController {

    public static final Logger log = LoggerFactory.getLogger(RemoteCallsController.class);
    @Resource
    private RemoteCallsService remoteCallsService;

    @Resource
    private CasesImportService casesImportService;

    /**
     * 获取公共accessToken
     *
     * @return 响应类
     */
    @ApiOperation(value = "获取公共accessToken")
    @GetMapping("/getAccessToken")
    public AjaxResult getAccessToken() {

        return success(remoteCallsService.getAccessToken());
    }

    /**
     * 事件进度推送接口
     *
     * @param allPush 是否全推送 1为推送当天上个小时 null为推送所有
     * @return 响应类
     */
    @ApiOperation(value = "事件进度推送接口")
    @GetMapping("/imports/{allPush}")
    public AjaxResult imports(@PathVariable("allPush") Integer allPush) {
        remoteCallsService.imports(allPush);
        return success();
    }

    /**
     * 根据起始时间运行算法
     *
     * @param startTime 开始时间 yyyy-MM-dd hh:mm:ss
     * @return 响应类
     */
    @ApiOperation(value = "根据起始时间运行算法")
    @GetMapping("/algorithm")
    public AjaxResult algorithm(@RequestParam("startTime") String startTime) {
        // 起始时间
        LocalDateTime start = LocalDateTimeUtil.parse(startTime, "yyyy-MM-dd");
        LocalDateTime now = LocalDateTime.now();
        // 获取当前时间
        LocalDateTime wholeHour = now.withMinute(0).withSecond(0);
        String localDateStr = wholeHour.format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
        while (start.isBefore(now)) {
            DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
            String yesterdayStr = start.format(formatter);
            log.info("--------------------------------------紧急事件接口起始时间"+yesterdayStr);
            // 紧急事件接口
            remoteCallsService.urgentAlgorithm(yesterdayStr);
            log.info("--------------------------------------重点人员接口起始时间"+yesterdayStr);
            // 重点人员接口
            remoteCallsService.keypersonAlgorithm();
            start = start.plusDays(1);
        }
        log.info("--------------------------------------群体事件接口");
        // 群体事件接口
        remoteCallsService.groupAlgorithm();
        log.info("--------------------------------------同人事件接口");
        // 同人事件接口
        remoteCallsService.onepersonAlgorithm();
        log.info("--------------------------------------过滤审核不通过的事件列表");
        // 过滤审核不通过的事件列表
        remoteCallsService.noPassEventList(startTime, localDateStr);
        log.info("--------------------------------------过滤已办结的事件列表");
        // 过滤已办结的事件列表
        remoteCallsService.completionEventList(startTime, localDateStr);
        return success();
    }
    /**
     * 获取社会治理中心增量事件保存到events_import表
     *
     * @return 响应类
     */
    @ApiOperation(value = "获取社会治理中心增量事件保存到events_import表")
    @GetMapping("/getEventDate")
    public AjaxResult getEventDate() {
        remoteCallsService.getEventDate();
        return success();
    }

    /**
     * 过滤审核不通过的事件列表
     *
     * @return 响应类
     */
    @ApiOperation(value = "过滤审核不通过的事件列表")
    @GetMapping("/noPassEventList")
    public AjaxResult noPassEventList() {
        // 获取当前时间
        LocalDateTime now = LocalDateTime.now();
        // 获取当前时间的上一个小时
        LocalDateTime lastHour = now.minusHours(1);
        // 获取上个小时
        LocalDateTime lastHourWholeHour = lastHour.withMinute(0).withSecond(0);
        String lastHourStr = lastHourWholeHour.format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
        // 获取当前时间
        LocalDateTime wholeHour = now.withMinute(0).withSecond(0);
        String localDateStr = wholeHour.format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
        remoteCallsService.noPassEventList(lastHourStr, localDateStr);
        return success();
    }

    /**
     * 过滤已办结的事件列表
     *
     * @return 响应类
     */
    @ApiOperation(value = "过滤已办结的事件列表")
    @GetMapping("/completionEventList")
    public AjaxResult completionEventList() {
        // 获取当前时间
        LocalDateTime now = LocalDateTime.now();
        // 获取当前时间的上一个小时
        LocalDateTime lastHour = now.minusHours(1);
        // 获取上个小时
        LocalDateTime lastHourWholeHour = lastHour.withMinute(0).withSecond(0);
        String lastHourStr = lastHourWholeHour.format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
        // 获取当前时间
        LocalDateTime wholeHour = now.withMinute(0).withSecond(0);
        String localDateStr = wholeHour.format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
        remoteCallsService.completionEventList(lastHourStr, localDateStr);
        return success();
    }

    /**
     * 更新算法数据并推送
     *
     * @param type type为0推送昨天数据
     * @return 响应类
     */
    @ApiOperation(value = "更新算法数据并推送")
    @GetMapping("/pushDate")
    public AjaxResult pushData(@RequestParam("type") Integer type) {
        // 获取当前时间
        LocalDateTime now = LocalDateTime.now();
        // 获取当前时间的上一个小时
        LocalDateTime lastHour = now.minusHours(1);
        // 获取上个小时
        LocalDateTime lastHourWholeHour = lastHour.withMinute(0).withSecond(0);
        String lastHourStr = lastHourWholeHour.format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
        // 获取当前时间
        LocalDateTime wholeHour = now.withMinute(0).withSecond(0);
        String localDateStr = wholeHour.format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
        // 过滤审核不通过的事件列表
        remoteCallsService.noPassEventList(lastHourStr, localDateStr);
        // 过滤已办结的事件列表
        remoteCallsService.completionEventList(lastHourStr, localDateStr);
        // 获取社会治理中心增量事件保存到events_import表
        remoteCallsService.getEventDate();
        // 拉取数据
        LocalDate localDate = LocalDate.now();
        if (type == 0) {
            localDate = localDate.minusDays(1);
        }
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
        String yesterdayStr = localDate.format(formatter);
        // 紧急事件接口
        remoteCallsService.urgentAlgorithm(yesterdayStr);
        // 重点人员接口
        remoteCallsService.keypersonAlgorithm();
        // 群体事件接口
        remoteCallsService.groupAlgorithm();
        // 同人事件接口
        remoteCallsService.onepersonAlgorithm();
        // 推送
        remoteCallsService.imports(1);
        return success();
    }

    /**
     * 算法处理所有数据
     *
     * @return 响应类
     */
    @ApiOperation(value = "算法处理所有数据")
    @GetMapping("/urgentAlgorithm")
    public AjaxResult urgentAlgorithm() {
        List<String> list = casesImportService.findDate();
        list.forEach(x -> remoteCallsService.urgentAlgorithm(x));
        return success();
    }

    /**
     * 调用过滤办结和作废接口
     *
     * @return 响应类
     */
    @ApiOperation(value = "调用过滤办结和作废接口")
    @GetMapping("/callTheAPI/{type}")
    public AjaxResult callTheAPI(@PathVariable("type") Integer type) {
        String lastHourStr = null;
        String localDateStr = null;
        if (type == 1) {
            // 获取当前时间
            LocalDateTime now = LocalDateTime.now();
            // 获取当前时间的上一个小时
            LocalDateTime lastHour = now.minusHours(1);
            // 获取上个小时
            LocalDateTime lastHourWholeHour = lastHour.withMinute(0).withSecond(0);
            lastHourStr = lastHourWholeHour.format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
            // 获取当前时间
            LocalDateTime wholeHour = now.withMinute(0).withSecond(0);
            localDateStr = wholeHour.format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
        }

        log.info("==============开始调用" + localDateStr + "============");
        // 过滤审核不通过的事件列表
        remoteCallsService.noPassEventList(lastHourStr, localDateStr);
        // 过滤已办结的事件列表
        remoteCallsService.completionEventList(lastHourStr, localDateStr);
        return success();
    }

    /**
     * 根据事件id推送接口
     *
     * @param innerEventId 事件id
     * @return 响应类
     */
    @ApiOperation(value = "事件进度推送接口")
    @GetMapping("/pushByInnerEventId/{innerEventId}")
    public AjaxResult pushById(@PathVariable("innerEventId") String innerEventId) {
        remoteCallsService.pushByInnerEventId(innerEventId);
        return success();
    }
}
