package com.ruoyi.pt.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.pt.entity.RemoteLog;
import com.ruoyi.pt.service.RemoteLogService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.Serializable;
import java.util.List;

/**
 * 算法日志表(RemoteLog)表控制层
 *
 * @author wu
 * @since 2024-02-22 09:56:40
 */
@RestController
@RequestMapping("pt/remoteLog")
@Api(tags = "算法日志表")
@Transactional(rollbackFor = Exception.class)
public class RemoteLogController extends BaseController {
    /**
     * 服务对象
     */
    @Resource
    private RemoteLogService remoteLogService;

    /**
     * 分页条件查询所有数据
     *
     * @param page      分页条件
     * @param remoteLog 查询条件
     * @return 所有数据
     */
    @GetMapping
    @ApiOperation(value = "分页条件查询算法日志表", response = RemoteLog.class)
    public AjaxResult page(Page<RemoteLog> page, RemoteLog remoteLog) {
        QueryWrapper<RemoteLog> wrapper = new QueryWrapper<>(remoteLog);
        wrapper.orderByDesc("running_time");
        if(remoteLog.getStartTime()!=null){
            wrapper.ge("running_time", remoteLog.getStartTime()); // 大于等于开始日期
        }
        if(remoteLog.getEndTime()!=null){
            wrapper.le("running_time", remoteLog.getEndTime());   // 小于等于结束日期
        }
        return success(remoteLogService.page(page, wrapper));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    @ApiOperation(value = "通过主键查询单条算法日志表", response = RemoteLog.class)
    public AjaxResult getById(@PathVariable Serializable id) {
        return success(remoteLogService.getById(id));
    }

    /**
     * 新增数据
     *
     * @param remoteLog 实体对象
     * @return 新增结果
     */
    @PostMapping
    @ApiOperation(value = "新增算法日志表", response = RemoteLog.class)
    public AjaxResult insert(@RequestBody RemoteLog remoteLog) {
        return success(remoteLogService.save(remoteLog));
    }

    /**
     * 修改数据
     *
     * @param remoteLog 实体对象
     * @return 修改结果
     */
    @PutMapping
    @ApiOperation(value = "修改算法日志表")
    public AjaxResult update(@RequestBody RemoteLog remoteLog) {
        return success(remoteLogService.updateById(remoteLog));
    }

    /**
     * 删除数据
     *
     * @param idList 主键集合
     * @return 删除结果
     */
    @DeleteMapping
    @ApiOperation(value = "删除算法日志表")
    public AjaxResult delete(@RequestParam("idList") List<Long> idList) {
        return success(remoteLogService.removeByIds(idList));
    }
}

