package com.ruoyi.pt.quartz;

import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.pt.entity.Keyperson;
import com.ruoyi.pt.service.KeypersonService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;

/**
 * 获取重点人员数据
 *
 * @author wu
 * @since 2024/4/26 下午5:30
 */
@Component
@EnableScheduling
@Async
@Transactional(rollbackFor = Exception.class)
//@RestController
//@RequestMapping("remoteCall/test")
//@Api(tags = "获取重点人员数据")
public class KeypersonQuartz {

    public static final Logger log = LoggerFactory.getLogger(KeypersonQuartz.class);

    @Resource
    private KeypersonService keypersonService;

    @Value("${keyPersonUrl}")
    private String keyPersonUrl;

    //    @GetMapping("/zdry")
//    @ApiOperation(value = "获取重点人员数据")
    @Scheduled(cron = "0 30 2 * * ?")
    public synchronized void pushData() {
        log.info("==============获取重点人员数据开始" + LocalDateTime.now() + "============");

        String res = HttpRequest.get(keyPersonUrl)
                .header("appId", "szjsc")
                .header("appSecret", "cUuC51fB").execute().body();
        JSONObject resObj = JSON.parseObject(res);
        String dataList = resObj.getString("data");
        List<Keyperson> list = JSONUtil.toList(dataList, Keyperson.class);
        log.info("==============获取重点人员数据条数" + list.size() + "============");
        // 删除重点人员数据
        keypersonService.delAll();
        // 保存重点人员数据
        keypersonService.saveBatch(list);
        log.info("==============获取重点人员数据结束" + LocalDateTime.now() + "============");
    }
}
