package com.ruoyi.pt.quartz;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.io.unit.DataUnit;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.pt.entity.RemoteLog;
import com.ruoyi.pt.service.RemoteCallsService;
import com.ruoyi.pt.service.RemoteLogService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.concurrent.TimeUnit;

/**
 * 推送平台数据定时任务
 *
 * @author wu
 * @since 2023/12/26 16:19
 */
@Component
@EnableScheduling
@Async
public class PushQuartz {

    public static final Logger log = LoggerFactory.getLogger(PushQuartz.class);
    @Resource
    private RemoteCallsService remoteCallsService;

    @Resource
    private RedisCache redisCache;

    @Resource
    private RemoteLogService remoteLogService;

    @Scheduled(cron = "0 0 */1 * * ?")
    public synchronized void pushData() {
        try {
            // 日志
            RemoteLog remoteLog = new RemoteLog();
            // 获取当前时间
            LocalDateTime now = LocalDateTime.now();
            remoteLog.setRunningTime(now);
            // 获取当前时间的上一个小时
            LocalDateTime lastHour = now.minusHours(1);
            // 获取上个小时
            LocalDateTime lastHourWholeHour = lastHour.withMinute(0).withSecond(0);
            String lastHourStr = lastHourWholeHour.format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
            // 获取当前时间
            LocalDateTime wholeHour = now.withMinute(0).withSecond(0);
            String localDateStr = wholeHour.format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
            log.info("==============开始定时任务" + localDateStr + "============");
            // 过滤审核不通过的事件列表
            log.info("==============过滤审核不通过的事件列表" + "============");
            remoteCallsService.noPassEventList(lastHourStr, localDateStr);
            // 过滤已办结的事件列表
            log.info("==============过滤已办结的事件列表" + "============");
            remoteCallsService.completionEventList(lastHourStr, localDateStr);
            // 拉取社会治理中心增量事件保存到events_import表
            int total = remoteCallsService.getEventDate();
            remoteLog.setHqTotal(total);
            // 获取今天的时间
            LocalDate localDate = LocalDate.now();
            DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
            String localTimeStr = localDate.format(formatter);
            // 紧急事件接口
            log.info("==============推送紧急事件接口" + LocalDateTime.now() + "============");
            remoteCallsService.urgentAlgorithm(localTimeStr);
            // 重点人员接口
            log.info("==============推送重点人员接口" + LocalDateTime.now() + "============");
            remoteCallsService.keypersonAlgorithm();
            // 群体事件接口
            log.info("==============推送群体事件接口" + LocalDateTime.now() + "============");
            remoteCallsService.groupAlgorithm();
            // 同人同诉接口
            log.info("==============推送同人同诉接口" + LocalDateTime.now() + "============");
            remoteCallsService.samepersonComplaint();
            // 一人多诉接口
            log.info("==============推送一人多诉接口" + LocalDateTime.now() + "============");
            remoteCallsService.onepersonSues();
            // 推送
            log.info("==============推送到预警平台接口" + LocalDateTime.now() + "============");
            int num = remoteCallsService.imports(1);
            remoteLog.setTsTotal(num);
            // 保存日志
            remoteLogService.save(remoteLog);
        }catch (Exception e){
            if(redisCache.hasKey("isNo")){
                redisCache.deleteObject("isNo");
                redisCache.setCacheObject("isNo", DateUtil.now(),6, TimeUnit.HOURS);
            }else {
                redisCache.setCacheObject("isNo", DateUtil.now(),6, TimeUnit.HOURS);
            }
        }
    }
}
