package com.ruoyi.pt.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.IdUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.pt.entity.CasesImport;
import com.ruoyi.pt.entity.Events;
import com.ruoyi.pt.entity.dto.AEventChangeIsReport;
import com.ruoyi.pt.entity.dto.AMassEventsRequest;
import com.ruoyi.pt.entity.response.ANew100PageResponse;
import com.ruoyi.pt.entity.response.FiveEventCountResponse;
import com.ruoyi.pt.mapper.AEventsMapper;
import com.ruoyi.pt.service.AEventsService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;

/**
 * 群体事件业务处理层
 *
 * @author du
 * @since 2024/9/2 10:24
 */
@Service
public class AEventsServiceImpl implements AEventsService {
    @Resource
    private RedisCache redisCache;
    @Resource
    private AEventsMapper aEventsMapper;


    /**
     * 分页条件查询事件表
     */
    @Override
    public Page<Events> page(Page<Events> page, AMassEventsRequest events) {
        Page<Events> page1 = aEventsMapper.page(page, events);
        for (Events ev : page1.getRecords()) {
            String str = ev.getRelationNums().replaceAll("[\\[\\]']", "");
            List<String> list = Arrays.asList(str.split(",\\s*"));
            if (!list.isEmpty()) {
                CasesImport byId = aEventsMapper.getById(list.get(0));
                ev.setAddress(byId.getCaseAddress());
            }
        }

        return page1;
    }


    /**
     * 分页条件查询审核列表
     */
    @Override
    public Page<CasesImport> auditList(Page<CasesImport> page, String innerEventId) {
        //获取该事件详细信息
        Events ev = aEventsMapper.getByInnerEventId(innerEventId);
        String str = ev.getRelationNums().replaceAll("[\\[\\]']", "");
        return aEventsMapper.auditList(page, Arrays.asList(str.split(",\\s*")));
    }

    /**
     * 查询工单详情
     */
    @Override
    public CasesImport getById(String id) {
        return aEventsMapper.getById(id);
    }

    /**
     * 修改事件标题
     */
    @Override
    public int edit(Events events) {
        return aEventsMapper.edit(events);
    }


    /**
     * 事件提级或退回
     *
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void eventChangeIsReport(AEventChangeIsReport events) {
        events.setAuditTime(DateUtil.date());
        //如果工单编号数组不为0,则将其所有工单进行标记
        if(events.getCaseSerial() != null && !events.getCaseSerial().isEmpty()){
            aEventsMapper.updateCasesImport(events.getCaseSerial(), DateUtil.now());
        }
        aEventsMapper.updateEvent(events);
        if (events.getIsReport() == 1) {
            Events a1 = aEventsMapper.getByInnerEventId(events.getInnerEventId());
            StringBuilder sb = new StringBuilder().append("[");
            int count = 1;
            for (String x : events.getCaseSerial()) {
                sb.append("'");
                sb.append(x);
                sb.append("'");
                if (count != events.getCaseSerial().size()) {
                    sb.append(",");
                }
                count++;
            }
            sb.append("]");
            a1.setRelationNums(sb.toString());
            String substring = a1.getInnerEventId().substring(0, 6);
            a1.setInnerEventId(substring + IdUtil.randomUUID());
            aEventsMapper.addAudit(a1);
        }
    }

    /**
     * 根据100条最新事件查询对应工单
     */
    @Override
    public List<ANew100PageResponse> new100Page() {
        //查询最新100条事件
        Page<Events> page1 = new Page<>();
        page1.setCurrent(1);
        page1.setSize(100);
        Page<Events> page = aEventsMapper.page(page1, new AMassEventsRequest());
        Map<String, String> msg = new HashMap<>();
        List<String> a1 = new ArrayList<>();
        page.getRecords().forEach(x -> {
            String[] split = x.getRelationNums().replaceAll("[\\[\\]']", "").split(",\\s*");
            if (split.length > 0) {
                a1.add(split[0]);
                msg.put(split[0], x.getInnerEventId());
            }
        });
        List<ANew100PageResponse> new100PageList = aEventsMapper.new100Page(a1);
        new100PageList.forEach(y -> {
            String s = msg.get(y.getCaseSerial());
            page.getRecords().forEach(x -> {
                if (s!=null&&s.equals(x.getInnerEventId())) {
                    y.setNums(x.getNums());
                    y.setMsgType(x.getMsgType());
                    y.setInnerEventId(x.getInnerEventId());
                    y.setRelationNums(x.getRelationNums());
                    y.setAuditTime(x.getAuditTime());
                    y.setEventTime(x.getEventTime());
                    y.setFirstWarnTime(x.getFirstWarnTime());
                    y.setIsReport(x.getIsReport());
                    y.setMsgTypeName(x.getMsgTypeName());
                    y.setScenceName(x.getScenceName());
                    y.setScenceType(x.getScenceType());
                    y.setScenceTypeName(x.getScenceTypeName());
                    y.setState(x.getState());
                    y.setTitle(x.getTitle());
                    y.setTitleBefore(x.getTitleBefore());
                    y.setWarnFactor(x.getWarnFactor());
                }
            });
        });
        return new100PageList;
    }

    /**
     * 查询事件详情
     */
    @Override
    public Events getByInnerEventId(String innerEventId) {
        return aEventsMapper.getByInnerEventId(innerEventId);
    }

    /**
     * 取最新一条事件
     */
    @Override
    public Events limitOneMsg() {
        return aEventsMapper.limitOneMsg();
    }

    /**
     * 根据查询条件查询事件待审核个数
     *
     * @param events 查询条件
     * @return 所有数据
     */
    @Override
    public Integer eventPageCount(AMassEventsRequest events) {
        return aEventsMapper.eventPageCount(events);
    }

    /**
     * 查询五种事件待审核个数
     */
    @Override
    public List<FiveEventCountResponse> fiveEventCount() {
        return aEventsMapper.fiveEventCount();
    }

    /**
     * 获取日志错误信息
     */
    @Override
    public Object getErrorMsg() {
        if(redisCache.hasKey("isNo")){
            return redisCache.getCacheObject("isNo");
        }else {
            return null;
        }
    }
}
